.. _IFLRs:

IFLR objects
------------
*IFLR*, or *Indirectly Formatted Logical Record* objects, are meant for keeping numerical or binary data.
There are two categories of IFLRs: :ref:`Frame Data` for strictly formatted numerical data
and :ref:`No-Format Frame Data` for arbitrary data bytes.


.. toctree::
   :maxdepth: 2

   framedata
   nfframedata
   relations
